# Run this to characterise a remote.
# Load libraries
from sys import platform
import time
import gc
from machine import Pin, freq
from ir_rx.print_error import print_error  # Optional print of error codes

# Import all implemented classes
from ir_rx.nec import NEC_8, NEC_16, SAMSUNG
from ir_rx.sony import SONY_12, SONY_15, SONY_20
from ir_rx.philips import RC5_IR, RC6_M0
from ir_rx.mce import MCE

# Define the pin that will receive the data
p = Pin(16, Pin.IN)

# **** DISPLAY GREETING ****
s = """Test for IR receiver.
CheckIRData() for NEC 8 bit protocol,
CheckIRData(1) for NEC 16 bit,
CheckIRData(2) for Sony SIRC 12 bit,
CheckIRData(3) for Sony SIRC 15 bit,
CheckIRData(4) for Sony SIRC 20 bit,
CheckIRData(5) for Philips RC-5 protocol,
CheckIRData(6) for RC6 mode 0.
CheckIRData(7) for Microsoft Vista MCE.
CheckIRData(8) for Samsung.

Hit ctrl-c to stop, then disconnect and reconnect your Pico board. Press Stop/Restart afterwards."""

# User callback (function to print the received data)
def cb(data, addr, ctrl):
    if data < 0:  # For when the Data received is of the NEC protocol.
        print("Repeat code.")
    else:
        print(f"Data 0x{data:02x} Addr 0x{addr:04x} Ctrl 0x{ctrl:02x}")
        
    # The received data can be used here to decide what is to be printed for example
    if data == 0x16:
        print("Button 0 was pressed")
    elif data == 0x0c:
        print("Button 1 was pressed")
    elif data == 0x18:
        print("Button 2 was pressed")
    elif data == 0x5e:
        print("Button 3 was pressed")
    elif data == 0x08:
        print("Button 4 was pressed")
    elif data == 0x1c:
        print("Button 5 was pressed")
    elif data == 0x5a:
        print("Button 6 was pressed")
    elif data == 0x42:
        print("Button 7 was pressed")
    elif data == 0x52:
        print("Button 8 was pressed")
    elif data == 0x4a:
        print("Button 9 was pressed")
        
def CheckIRData(proto=0):
    # List of all possible protocols
    classes = (NEC_8, NEC_16, SONY_12, SONY_15, SONY_20, RC5_IR, RC6_M0, MCE, SAMSUNG)
    ir = classes[proto](p, cb) # Instantiate receiver
    ir.error_function(print_error) # Show debug information
    # ir.verbose = True
    try:
        while True:
            print("running")
            time.sleep(5)
            gc.collect()
    except KeyboardInterrupt:
        ir.close()

print(s)

# Continuous loop for continuous operation
while True:
    CheckIRData()